Module cmdline

Module cmdline 

Helper for creating valid kernel command line strings.

Structs

Cmdline
A builder for a kernel command line string that validates the string as its being built. A CString can be constructed from this directly using CString::new.

Enums

Error
The error type for command line building operations.

Type Aliases

Result
Specialized Result type for command line operations.