pub enum Error {
CommandLineCopy,
CommandLineOverflow,
InvalidAscii,
HasSpace,
HasEquals,
TooLarge,
}Expand description
The error type for command line building operations.
Variants
CommandLineCopy
Failed to copy to guest memory.
CommandLineOverflow
Command line string overflows guest memory.
InvalidAscii
Operation would have resulted in a non-printable ASCII character.
HasSpace
Key/Value Operation would have had a space in it.
HasEquals
Key/Value Operation would have had an equals sign in it.
TooLarge
Operation would have made the command line too large.