Module loader

Module loader 

Helper for loading a kernel image in the guest memory.

Enums

Error

Functions

load_cmdline
Writes the command line string to the given memory slice.

Type Aliases

Result