load_cmdline

Function load_cmdline 

pub fn load_cmdline(
    guest_mem: &GuestMemoryMmap,
    guest_addr: GuestAddress,
    cmdline: &CString,
) -> Result<(), Error>
Writes the command line string to the given memory slice.

Arguments

  • guest_mem - A u8 slice that will be partially overwritten by the command line.
  • guest_addr - The address in guest_mem at which to load the command line.
  • cmdline - The kernel command line as CString.