Module loader
krun_
kernel
0.1.0-1.19.0
Module loader
Module Items
Enums
Functions
Type Aliases
In crate krun_
kernel
krun_kernel
Module
loader
Helper for loading a kernel image in the guest memory.
Enums

Error
Functions

load_
cmdline
Writes the command line string to the given memory slice.
Type Aliases

Result